@@ -43,7 +43,6 @@ class Autocomplete:
         self.__options = options or {}
 
     def get_autocomplete_results(self, query, parameters=None, user_parameters=None):
-        # pylint: disable=line-too-long
         '''
         Retrieve autocomplete results from API
 
@@ -51,7 +50,7 @@ class Autocomplete:
         :param dict parameters: Additional parameters to refine result set
         :param int parameters.num_results: The total number of results to return
         :param dict parameters.filters: Filters used to refine search
-        :param int parameters.results_per_section: Number of results to return per section
+        :param dict parameters.results_per_section: Number of results to return per section
         :param list parameters.hidden_fields: Hidden metadata fields to return
         :param dict parameters.variations_map: The variations map dictionary to aggregate variations. Please refer to https://docs.constructor.io/rest_api/variations_mapping for details
         :param dict user_parameters: Parameters relevant to the user request
@@ -65,7 +64,6 @@ class Autocomplete:
 
         :return: dict
         '''
-        # pylint: enable=line-too-long
 
         if not parameters:
             parameters = {}
